Change rtti/Rtti to RTTI, as it is an acronym.


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@90334 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/CodeGenModule.h b/lib/CodeGen/CodeGenModule.h
index 78bc4ed..e5bd3e2 100644
--- a/lib/CodeGen/CodeGenModule.h
+++ b/lib/CodeGen/CodeGenModule.h
@@ -224,14 +224,14 @@
   /// GenerateVTT - Generate the VTT for the given type.
   llvm::Constant *GenerateVTT(const CXXRecordDecl *RD);
 
-  /// GenerateRtti - Generate the rtti information for the given type.
-  llvm::Constant *GenerateRtti(const CXXRecordDecl *RD);
-  /// GenerateRttiRef - Generate a reference to the rtti information for the
+  /// GenerateRTTI - Generate the rtti information for the given type.
+  llvm::Constant *GenerateRTTI(const CXXRecordDecl *RD);
+  /// GenerateRTTIRef - Generate a reference to the rtti information for the
   /// given type.
-  llvm::Constant *GenerateRttiRef(const CXXRecordDecl *RD);
-  /// GenerateRttiNonClass - Generate the rtti information for the given
+  llvm::Constant *GenerateRTTIRef(const CXXRecordDecl *RD);
+  /// GenerateRTTINonClass - Generate the rtti information for the given
   /// non-class type.
-  llvm::Constant *GenerateRtti(QualType Ty);
+  llvm::Constant *GenerateRTTI(QualType Ty);
 
   /// BuildThunk - Build a thunk for the given method.
   llvm::Constant *BuildThunk(const CXXMethodDecl *MD, bool Extern,